@@ -1,5 +1,5 @@
-from PySide2.QtWidgets           import QLineEdit
-from qtrf.mixins.float_line_edit import FloatLineEditMixin
+from PySide2.QtWidgets import QLineEdit
+from qtrf.mixins       import FloatLineEditMixin
 
 
 class FloatValueLineEdit(FloatLineEditMixin, QLineEdit):
